@@ -17,7 +17,7 @@ Destinations can be added by specifying the `onFailure` or `onSuccess` props whe
 The following destinations are supported
 
 * Lambda function
-* SQS queue
+* SQS queue - Only standard SQS queues are supported for failure destinations, FIFO queues are not supported.
 * SNS topic
 * EventBridge event bus
 
@@ -39,6 +39,24 @@ my_fn = lambda_.Function(self, "Fn",
 )
 ```
 
+Example with a SQS queue for unsuccessful invocations:
+
+```python
+# An sqs queue for unsuccessful invocations of a lambda function
+import aws_cdk.aws_sqs as sqs
+
+
+dead_letter_queue = sqs.Queue(self, "DeadLetterQueue")
+
+my_fn = lambda_.Function(self, "Fn",
+    runtime=lambda_.Runtime.NODEJS_12_X,
+    handler="index.handler",
+    code=lambda_.Code.from_inline("// your code"),
+    # sqs queue for unsuccessful invocations
+    on_failure=destinations.SqsDestination(dead_letter_queue)
+)
+```
+
 See also [Configuring Destinations for Asynchronous Invocation](https://docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#invocation-async-destinations).
 
 ### Invocation record
@@ -167,6 +185,8 @@ class EventBridgeDestination(
 
     If no event bus is specified, the default event bus is used.
 
+    :exampleMetadata: fixture=_generated
+
     Example::
 
         # The code below shows an example of how to instantiate this type.
@@ -216,6 +236,8 @@ class LambdaDestination(
 ):
     '''Use a Lambda function as a Lambda destination.
 
+    :exampleMetadata: infused
+
     Example::
 
         # Auto-extract response payload with a lambda destination
@@ -277,6 +299,8 @@ class LambdaDestinationOptions:
 
         :param response_only: Whether the destination function receives only the ``responsePayload`` of the source function. When set to ``true`` and used as ``onSuccess`` destination, the destination function will be invoked with the payload returned by the source function. When set to ``true`` and used as ``onFailure`` destination, the destination function will be invoked with the error object returned by source function. See the README of this module to see a full explanation of this option. Default: false The destination function receives the full invocation record.
 
+        :exampleMetadata: infused
+
         Example::
 
             # Auto-extract response payload with a lambda destination
@@ -333,6 +357,8 @@ class SnsDestination(
 ):
     '''Use a SNS topic as a Lambda destination.
 
+    :exampleMetadata: infused
+
     Example::
 
         # An sns topic for successful invocations of a lambda function
@@ -382,16 +408,23 @@ class SqsDestination(
 ):
     '''Use a SQS queue as a Lambda destination.
 
+    :exampleMetadata: infused
+
     Example::
 
-        # The code below shows an example of how to instantiate this type.
-        # The values are placeholders you should change.
-        import aws_cdk.aws_lambda_destinations as lambda_destinations
+        # An sqs queue for unsuccessful invocations of a lambda function
         import aws_cdk.aws_sqs as sqs
         
-        # queue is of type Queue
         
-        sqs_destination = lambda_destinations.SqsDestination(queue)
+        dead_letter_queue = sqs.Queue(self, "DeadLetterQueue")
+        
+        my_fn = lambda_.Function(self, "Fn",
+            runtime=lambda_.Runtime.NODEJS_12_X,
+            handler="index.handler",
+            code=lambda_.Code.from_inline("// your code"),
+            # sqs queue for unsuccessful invocations
+            on_failure=destinations.SqsDestination(dead_letter_queue)
+        )
     '''
 
     def __init__(self, queue: aws_cdk.aws_sqs.IQueue) -> None:
